Description Usage Arguments Details Methods (by generic) Slots Author(s)
S4 class encapsulating exon and junction information for a single "connected component" object.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 | concomp(obj, ...)
## S4 method for signature 'GRangesList'
concomp(obj)
## S4 method for signature 'data.frame'
concomp(obj)
## S4 method for signature 'concomp'
eRanges(object)
## S4 method for signature 'concomp'
jRanges(object)
## S4 method for signature 'concomp'
eCoverage(object)
## S4 method for signature 'concomp'
jCoverage(object)
## S4 replacement method for signature 'concomp'
eRanges(object) <- value
## S4 replacement method for signature 'concomp'
jRanges(object) <- value
## S4 replacement method for signature 'concomp'
eCoverage(object) <- value
## S4 replacement method for signature 'concomp'
jCoverage(object) <- value
## S4 method for signature 'concomp'
show(object)
|
obj |
primary input to |
... |
other parameters to be passed to constructor |
object |
a |
value |
new value for |
The constructor method obj parameter can be either:
a GRangesList with two GRanges named "e" and "j"
corresponding to exon and junction ranges and coverage for a
collection of samples to be used to construct a concomp object.
Both GRanges must have one metadata for each sample
(named sequentially: 's1', 's2', ...), giving the corresponding exon or
splice junction coverages.
a data.frame with gene model columns: 'chr', 'seqlengths',
'gStart', 'gStop', and 'kind' (e.g. 'e' or 'j'),
as well as per-sample coverage columns: 's1', 's2', ...
eRanges: get eRanges slot
jRanges: get jRanges slot
eCoverage: get eCoverage slot
jCoverage: get jCoverage slot
eRanges<-: set eRanges slot
jRanges<-: set jRanges slot
eCoverage<-: set eCoverage slot
jCoverage<-: set jCoverage slot
eRangesa GRanges object containing the exonic information
jRangesa GRanges object containing the junction information
eCoveragea matrix of exon coverage values, e.g. RPKM, with
number of rows equal to the length of exons, or NULL
if not available
jCoveragea matrix of junction coverage values, e.g. number of
spanning reads, with number of rows equal to the length of
juncs, or NULL if not available
Patrick Kimes
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.